@@ -53,6 +53,12 @@ static const char cright_years_z[] =
 
 /* Reworked to GNU style by Ian Lance Taylor, ian@airs.com, August 93.  */
 
+/*=======================================================\
+| uuencode [INPUT] OUTPUT				 |
+| 							 |
+| Encode a file so it can be mailed to a remote system.	 |
+\=======================================================*/
+
 #include "local.h"
 
 #if HAVE_LOCALE_H
@@ -61,12 +67,10 @@ static const char cright_years_z[] =
 #endif
 #define _(str) gettext (str)
 
-/*=======================================================\
-| uuencode [INPUT] OUTPUT				 |
-| 							 |
-| Encode a file so it can be mailed to a remote system.	 |
-\=======================================================*/
-
+#if __CYGWIN__
+# include <fcntl.h>
+# include <io.h>
+#endif
 
 #define	RW (S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)
 
@@ -264,6 +268,10 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
     case 2:
       /* Optional first argument is input file.  */
       {
+#if S_IRWXU != 0700
+        choke me - Must translate mode argument
+#endif
+
 	FILE *fp = freopen (argv[optind], FOPEN_READ_BINARY, stdin);
 	if (fp != stdin)
 	  error (EXIT_FAILURE, errno, _("fopen-ing %s"), argv[optind]);
@@ -275,7 +283,7 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
       }
 
     case 1:
-#if __CYGWIN
+#if __CYGWIN__
       if (! isatty (STDIN_FILENO))
        setmode (STDIN_FILENO, O_BINARY);
 #endif
@@ -288,10 +296,6 @@ warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
       usage (EXIT_FAILURE);
     }
 
-#if S_IRWXU != 0700
-choke me - Must translate mode argument
-#endif
-
   if (printf ("begin%s %o %s\n", trans_ptr == uu_std ? "" : "-base64",
 	      mode, argv[optind]) < 0)
     error (EXIT_FAILURE, errno, _("Write error"));
